@@ -9,10 +9,12 @@ Usage::
         Client,
         ListBatchInferenceJobsPaginator,
         ListCampaignsPaginator,
+        ListDatasetExportJobsPaginator,
         ListDatasetGroupsPaginator,
         ListDatasetImportJobsPaginator,
         ListDatasetsPaginator,
         ListEventTrackersPaginator,
+        ListFiltersPaginator,
         ListRecipesPaginator,
         ListSchemasPaginator,
         ListSolutionVersionsPaginator,
@@ -27,10 +29,12 @@ Usage::
 
     list_batch_inference_jobs_paginator: ListBatchInferenceJobsPaginator = client.get_paginator("list_batch_inference_jobs")
     list_campaigns_paginator: ListCampaignsPaginator = client.get_paginator("list_campaigns")
+    list_dataset_export_jobs_paginator: ListDatasetExportJobsPaginator = client.get_paginator("list_dataset_export_jobs")
     list_dataset_groups_paginator: ListDatasetGroupsPaginator = client.get_paginator("list_dataset_groups")
     list_dataset_import_jobs_paginator: ListDatasetImportJobsPaginator = client.get_paginator("list_dataset_import_jobs")
     list_datasets_paginator: ListDatasetsPaginator = client.get_paginator("list_datasets")
     list_event_trackers_paginator: ListEventTrackersPaginator = client.get_paginator("list_event_trackers")
+    list_filters_paginator: ListFiltersPaginator = client.get_paginator("list_filters")
     list_recipes_paginator: ListRecipesPaginator = client.get_paginator("list_recipes")
     list_schemas_paginator: ListSchemasPaginator = client.get_paginator("list_schemas")
     list_solution_versions_paginator: ListSolutionVersionsPaginator = client.get_paginator("list_solution_versions")
@@ -41,10 +45,12 @@ from mypy_boto3_personalize.client import PersonalizeClient
 from mypy_boto3_personalize.paginator import (
     ListBatchInferenceJobsPaginator,
     ListCampaignsPaginator,
+    ListDatasetExportJobsPaginator,
     ListDatasetGroupsPaginator,
     ListDatasetImportJobsPaginator,
     ListDatasetsPaginator,
     ListEventTrackersPaginator,
+    ListFiltersPaginator,
     ListRecipesPaginator,
     ListSchemasPaginator,
     ListSolutionsPaginator,
@@ -58,10 +64,12 @@ __all__ = (
     "Client",
     "ListBatchInferenceJobsPaginator",
     "ListCampaignsPaginator",
+    "ListDatasetExportJobsPaginator",
     "ListDatasetGroupsPaginator",
     "ListDatasetImportJobsPaginator",
     "ListDatasetsPaginator",
     "ListEventTrackersPaginator",
+    "ListFiltersPaginator",
     "ListRecipesPaginator",
     "ListSchemasPaginator",
     "ListSolutionVersionsPaginator",
